from .file_utils import *

def DLProjectTemplate(root, template=None):
    """Build a deep learning project from a given template under directory `root`.

    Args:
        root: The root directory of the project.
        template: The template (todo).
    Returns:
        None
    """
    CreateFolder(pjoin(root,"data"))
    CreateFolder(pjoin(root,"models"))
    # TODO


from .file_utils import *
import seaborn as sns
import matplotlib as mpl
import matplotlib.pyplot as plt

class Plotter(object):
    """A wrapped pyplot pipeline with seaborn styling.
    """
    def __init__(self, figsize=(8,6), dpi=300, path=None, legend=True, sns_style='darkgrid'):
        self.figsize = figsize; self.dpi = dpi; self.path = path; self.legend = legend; self.sns_style = sns_style

    def __enter__(self):
        sns.set(style=self.sns_style)
        fig,axe = plt.subplots(figsize=self.figsize,dpi=self.dpi)
        return (fig,axe)

    def __exit__(self, exc_type, exc_val, exc_tb):
        if self.legend:
            plt.legend()
        if self.path is not None:
            CreateFile(self.path); plt.savefig(self.path)
        else:
            plt.show()
        plt.close()


from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name = "pyheaven",
    version = "0.1.5.5",
    author = "Magolor",
    author_email = "magolorcz@gmail.com",
    description = "Python Heaven",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url = "https://github.com/Magolor/",
    project_urls={
        "Author":"https://github.com/Magolor/",
    },
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    package_dir={"":"src"},
    packages=find_packages(where="src"),
    python_requires=">=3.7",
)



from .basic_utils import *
from .misc_utils import *
from .file_utils import *
from .serialize_utils import *
from .crypto_utils import *
from .args_utils import *
# from .torch_utils import *
# from .pyqt_utils import *